@@ -1,5 +1,5 @@
 package Amazon::DynamoDB::20120810;
-$Amazon::DynamoDB::20120810::VERSION = '0.32';
+$Amazon::DynamoDB::20120810::VERSION = '0.33';
 use strict;
 use warnings;
 
@@ -609,7 +609,7 @@ method _scan_or_query_process (Str $target,
                     $finished = 1;
                 } 
 
-                if (!defined($payload->{LastEvaluatedKey})) {
+                if (!defined($data->{LastEvaluatedKey})) {
                     $finished = 1;
                 } else {
                     if (!$finished) {
@@ -1009,7 +1009,7 @@ Amazon::DynamoDB::20120810
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 DESCRIPTION
 
